package com.rwk.system.mapper;

import java.util.List;
import com.rwk.system.domain.RwkMeetingStaff;

/**
 * 培训人员签到Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-05
 */
public interface RwkMeetingStaffMapper 
{
    /**
     * 查询培训人员签到
     * 
     * @param id 培训人员签到主键
     * @return 培训人员签到
     */
    public RwkMeetingStaff selectRwkMeetingStaffById(Long id);

    /**
     * 查询培训人员签到列表
     * 
     * @param rwkMeetingStaff 培训人员签到
     * @return 培训人员签到集合
     */
    public List<RwkMeetingStaff> selectRwkMeetingStaffList(RwkMeetingStaff rwkMeetingStaff);

    /**
     * 新增培训人员签到
     * 
     * @param rwkMeetingStaff 培训人员签到
     * @return 结果
     */
    public int insertRwkMeetingStaff(RwkMeetingStaff rwkMeetingStaff);

    /**
     * 修改培训人员签到
     * 
     * @param rwkMeetingStaff 培训人员签到
     * @return 结果
     */
    public int updateRwkMeetingStaff(RwkMeetingStaff rwkMeetingStaff);

    /**
     * 删除培训人员签到
     * 
     * @param id 培训人员签到主键
     * @return 结果
     */
    public int deleteRwkMeetingStaffById(Long id);

    /**
     * 批量删除培训人员签到
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRwkMeetingStaffByIds(String[] ids);
}
